@@ -20,6 +20,7 @@ from __future__ import print_function
 import argparse
 import contextlib
 import json
+from unittest import mock
 import os
 import re
 import sys
@@ -28,10 +29,10 @@ import unittest
 
 from absl.testing import absltest
 from absl.testing import parameterized
-from unittest import mock
-from refex import cli
 import six
 
+from refex import cli
+
 
 class ParseArgsLeftoversTest(absltest.TestCase):
 
@@ -387,7 +388,8 @@ class MainTest(MainTestBase):
   def test_sub_noiterate(self, extra_args):
     f = self.create_tempfile(content='foo')
     _ = self.main(
-        ['--mode=py.expr', 'foo', '--sub=wrap(foo)', '-i', f.full_path] + extra_args)
+        ['--mode=py.expr', 'foo', '--sub=wrap(foo)', '-i', f.full_path] +
+        extra_args)
     self.assertEqual(f.read_text(), 'wrap(foo)')
 
   @parameterized.parameters(
@@ -397,7 +399,8 @@ class MainTest(MainTestBase):
   def test_sub_iterate(self, extra_args):
     f = self.create_tempfile(content='foo')
     _ = self.main(
-        ['--mode=py.expr', 'foo', '--sub=wrap(foo)', '-i', f.full_path] + extra_args)
+        ['--mode=py.expr', 'foo', '--sub=wrap(foo)', '-i', f.full_path] +
+        extra_args)
     self.assertStartsWith(f.read_text(), 'wrap(wrap(wrap(')
     self.assertEndsWith(f.read_text(), ')))')
 
@@ -726,6 +729,13 @@ class MainTest(MainTestBase):
         ['--mode=py.stmt', 'x = $f()', '--no-filename', f.full_path])
     self.assertEqual(output, 'x = foo()\n')
 
+  def test_py_stmt_sub(self):
+    f = self.create_tempfile(content='a = b\n')
+
+    output = self.main(
+        ['--mode=py.stmt', '$x = $y', '--sub', '$y = $x', '-i', f.full_path])
+    self.assertEqual(f.read_text(), 'b = a\n')
+
   def test_py_ez_sub(self):
     """$f and $foo will be treated as separate variables."""
     for mode in ['py.expr', 'py.stmt']:
